{% extends "bee_django_crm/base.html" %}
{% load static %}
{% block content %}
    {% include 'bee_django_crm/logo.html' %}
    {% include 'bee_django_crm/nav.html' %}
    <form method="post">
        {% csrf_token %}

        {{ form.as_ul }}

        <input type="submit" value="提交"/>
    </form>
{% endblock %}


{% block scripts %}
    <script>
        $(document).ready(function () {
            //时间
            $.datetimepicker.setLocale('ch');
            var $birthday = $("#id_tracked_at");
            $birthday.datetimepicker({
                format: 'Y-m-d H:i',
                step: 30,
                scrollMonth: false,
                scrollTime: false,
                scrollInput: false
            });

        });
    </script>
{% endblock %}