{% extends "bee_django_crm/base.html" %}
{% load static %}
{% block styles %}
    <style>

        body {
            margin: 0;
            padding: 0;
            background-color: #f5f5f5;

        }

    </style>
{% endblock %}
{% block content %}
    {% for message in messages %}
        {% if message.tags == "success" and forloop.counter == 1 %}
            <div>
                <div class="text-center" style="margin-top:100px;">
                    <img src="{% static 'bee_django_crm/img/preuser_done.jpg' %}" alt="注册成功">
                </div>
                <div class="text-center">
                    <h3>
                            <span style="font-weight: 900;">{{ message }}</span>
                    </h3>
                    稍后我们的课程顾问会与您联系，感谢您的耐心等待。
                </div>
            </div>

        {% elif message.tags == "error" and forloop.counter == 1 %}
            <div>
{#                <div class="text-center" style="margin-top:100px;">#}
{#                    <img src="{% static 'bee_django_crm/img/preuser_done.jpg' %}" alt="注册成功">#}
{#                </div>#}
                <div class="text-center">
                    <h3>
                            <span style="font-weight: 900;">{{ message }}</span>
                    </h3>
                    <div><button onclick="click_prev()" class="btn btn-default">返回</button></div>
                </div>
            </div>
        {% endif %}
    {% endfor %}



{% endblock %}
{% block scripts %}
    <script>
        function click_prev(){
            window.history.back();
        }
    </script>
{% endblock %}