<style>
    .logo {
        background-color: #4B6788;
        height: 60px;
        color: #ffffff;
        font-size: 30px;
        padding: 10px;
    }
</style>

<div class="logo">crm管理系统 <span style="font-size: 14px;"> v 1.4.39</span>
</div>

