# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-05-06 08:47
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0022_auto_20190422_1925'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='regcode',
            options={'ordering': ['-pk'], 'permissions': (('can_ckeck_code', '\u53ef\u4ee5\u9a8c\u8bc1\u5361\u5bc6'), ('can_get_code', '\u53ef\u4ee5\u83b7\u53d6\u5361\u5bc6'))},
        ),
    ]
