<style>
    .preuser_nav {
        padding: 10px;
    }
</style>
<div class="preuser_nav">
    <a href="{% url 'bee_django_crm:preuser_list' %}?level=1" class="btn btn-default">小白</a>
    <a href="{% url 'bee_django_crm:preuser_list' %}?level=2" class="btn btn-default">申请</a>
    <a href="{% url 'bee_django_crm:preuser_list' %}?level=3" class="btn btn-default">缴费</a>
    <a href="{% url 'bee_django_crm:preuser_list' %}?level=4" class="btn btn-default">课程卡</a>
</div>