{% load bee_django_crm_filter %}
<div class="text-center"><h3>课程卡</h3></div>
<table class="table">
    <thead>
    <tr>
        <th></th>
        <th>学号</th>
        <th>姓名</th>
        <th>电话</th>
        <th>省</th>
        <th>市</th>
        <th></th>

    </tr>
    </thead>
    <tbody>
    {% for preUser in preuser_list %}
        <tr>
            <td>{{ forloop.counter }} </td>
            <td>
                {% if preUser.get_user_username %}
                    <a href="{{ preUser.userprofile.user.get_user_search_link }}">{{ preUser.get_user_username }}</a>
                {% endif %}

            </td>
            <td>
                <a href="{% url 'bee_django_crm:preuser_detail' preUser.id %}?admin=1">{{ preUser.name }}</a>

            </td>
            <td>{{ preUser.mobile }}</td>
            <td>{{ preUser.province|default:"无" }}</td>
            <td>{{ preUser.city|default:"无" }}</td>
            <td>
                <a href="{% url 'bee_django_crm:preuser_detail' preUser.id %}">详情</a>
                {% if not preUser.userprofile and crm_after_check %}
                    <a href="{% url 'bee_django_crm:code_user_create' %}?preuser_id={{ preUser.id }}">创建账号</a>
                {% endif %}


            </td>
            <td>

            </td>


        </tr>


    {% endfor %}
    </tbody>
</table>
