# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-23 09:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0008_preuser_pay_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='applicationquestion',
            name='is_required',
            field=models.BooleanField(default=False, verbose_name=b'\xe6\x98\xaf\xe5\x90\xa6\xe5\xbf\x85\xe5\xa1\xab'),
        ),
    ]
