# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-01-10 05:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0014_auto_20181109_1336'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contract',
            name='duration',
            field=models.IntegerField(blank=True, null=True, verbose_name=b'\xe6\x97\xb6\xe9\x95\xbf'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='period',
            field=models.IntegerField(help_text=b'\xe5\xa6\x82\xe4\xb8\xba\xe9\x95\xbf\xe6\x9c\x9f\xef\xbc\x8c\xe5\x88\x99\xe4\xb8\x8d\xe7\x94\xa8\xe5\xa1\xab\xe5\x86\x99\xe6\x97\xb6\xe9\x95\xbf', verbose_name=b'\xe5\x91\xa8\xe6\x9c\x9f'),
        ),
    ]
