# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-23 07:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0006_auto_20180822_1736'),
    ]

    operations = [
        migrations.AlterField(
            model_name='preuserfee',
            name='info',
            field=models.TextField(blank=True, null=True, verbose_name=b'\xe5\xa4\x87\xe6\xb3\xa8'),
        ),
        migrations.AlterField(
            model_name='preuserfee',
            name='pay_status',
            field=models.IntegerField(choices=[(1, b'\xe5\x85\xa8\xe6\xac\xbe'), (2, b'\xe5\x88\x86\xe6\x9c\x9f\xe5\xa4\xb4\xe6\xac\xbe'), (3, b'\xe5\x88\x86\xe6\x9c\x9f\xe4\xb8\xad'), (4, b'\xe5\x88\x86\xe6\x9c\x9f\xe5\xb0\xbe\xe6\xac\xbe')], default=1, verbose_name=b'\xe4\xbb\x98\xe6\xac\xbe\xe6\x96\xb9\xe5\xbc\x8f\xe5\x8f\x8a\xe7\x8a\xb6\xe6\x80\x81'),
        ),
        migrations.AlterField(
            model_name='preuserfee',
            name='study_at',
            field=models.DateTimeField(blank=True, help_text=b'\xe3\x80\x90\xe5\x85\xa8\xe6\xac\xbe\xe3\x80\x91\xe5\x8f\x8a\xe3\x80\x90\xe5\x88\x86\xe6\x9c\x9f\xe5\xa4\xb4\xe6\xac\xbe\xe3\x80\x91\xe6\x97\xb6\xef\xbc\x8c\xe6\xad\xa4\xe5\xad\x97\xe6\xae\xb5\xe5\xbf\x85\xe5\xa1\xab\xe3\x80\x82\xe5\x85\xb6\xe4\xbb\x96\xe4\xbb\x98\xe6\xac\xbe\xe6\x96\xb9\xe5\xbc\x8f\xe5\x8f\xaf\xe4\xb8\x8d\xe5\xa1\xab\xe5\x86\x99', null=True, verbose_name=b'\xe5\xbc\x80\xe8\xaf\xbe\xe6\x97\xa5\xe6\x9c\x9f'),
        ),
    ]
