{% extends "bee_django_crm/base.html" %}
{% load bootstrap3 %}
{% load static %}
{% block content %}
    {% include 'bee_django_crm/logo.html' %}
    {% include 'bee_django_crm/nav.html' %}
    <div style="margin: 5px 0;">
        <form method="post">
            {% csrf_token %}

                    {% bootstrap_form form %}
{#            {{ form.agreement.errors }}#}
            {#        {{ form.non_field_errors }}#}
            {#                <div>#}
            {#                    {{ form.name.errors }}#}
            {#                    {{ form.name }}#}
            {#                </div><div>#}
            {#                    {{ form.period.errors }}#}
            {#                    {{ form.period }}#}
            {#                </div>#}
{#            <div id="editor"></div>#}
{#            <div style="display:none;">{{ form.agreement }}</div>#}
{#            <div id="edit_agreement" style="display:none;">{{ contract.agreement|default:''|safe }}</div>#}
            {% bootstrap_button '提交' %}
        </form>
    </div>
{% endblock %}


